@@ -4,7 +4,7 @@
 #' @importFrom stringdist stringdistmatrix
 #' @importFrom knitr purl
 #' @importFrom BiocManager available install repositories version
-#' @import biocViews httr methods
+#' @import biocViews methods
 
 # Checks for BiocCheck ----------------------------------------------------
 
@@ -96,7 +96,9 @@ checkVersionNumber <- function(pkgdir)
         x <- pv$major
         y <- pv$minor
         mod <- y %% 2
-        isDevel <- (BiocManager:::.version_bioc("devel") == BiocManager::version())
+        isDevel <- identical(
+            BiocManager:::.version_bioc("devel"), BiocManager::version()
+        )
         bioc.mod <- ifelse(isDevel, 1, 0)
         if (x == 0) {
             handleMessage("Package version ", as.character(pv), "; pre-release")
@@ -158,23 +160,67 @@ checkPackageSize <- function(pkg, pkgdir, size=5){
     }
 }
 
+.MAX_FILE_SIZE <- 5*10^6 ## 5MB
+.DATA_DIRS <- c("data", "inst/extdata", "data-raw")
+
+.filter_data <- function(filedf, for_data = FALSE) {
+    files <- filedf[["path"]]
+    data_dirs <- paste0(.DATA_DIRS, "/")
+    hitmat <- vapply(
+        data_dirs,
+        grepl,
+        logical(length(files)),
+        x = files,
+        fixed = TRUE
+    )
+    hits <- as.logical(rowSums(hitmat))
+    decision <- if (for_data) force else `!`
+    filedf[decision(hits), , drop = FALSE]
+}
+
+.in_data <- function(f) { f %in% .DATA_DIRS }
+
+.findLargeFiles <- function(pkgdir, data_only) {
+    gitignore <- file.exists(file.path(pkgdir, ".gitignore"))
+    if (requireNamespace("gert", quietly = TRUE) && gitignore) {
+        fileinfo <- gert::git_ls(repo = pkgdir)
+        fileinfo <- .filter_data(fileinfo, for_data = data_only)
+        files <- unlist(
+            fileinfo[fileinfo[["filesize"]] > .MAX_FILE_SIZE, "path"]
+        )
+        file.path(pkgdir, files)
+    } else {
+        folders <- list.dirs(pkgdir, full.names = FALSE, recursive = TRUE)
+        decision <- if (data_only) force else Negate
+        folders <- Filter(decision(.in_data), folders)
+        files <- list.files(
+            file.path(pkgdir, folders), full.names = TRUE, recursive = TRUE
+        )
+        filesizes <- file.size(files)
+        files[filesizes > .MAX_FILE_SIZE]
+    }
+}
+
 checkIndivFileSizes <- function(pkgdir)
 {
-    pkgType <- getPkgType(pkgdir)
-    if (is.na(pkgType) ||  pkgType == "Software") {
-        maxSize <- 5*10^6 ## 5MB
-        allFiles <- list.files(pkgdir, all.files=TRUE, recursive=TRUE)
-        allFilesFullName <- file.path(pkgdir, allFiles)
-        sizes <- file.size(allFilesFullName)
-        largeFiles <- paste(allFiles[sizes > maxSize], collapse=" ")
-        if (any(sizes > maxSize)) {
-            handleWarning(
-                "The following files are over 5MB in size: ",
-                paste0("'", largeFiles, "'", collapse = " ")
-            )
-            return(TRUE)
-        }
-    }
+    largefiles <- .findLargeFiles(pkgdir, data_only = FALSE)
+    if (length(largefiles))
+        handleWarning(
+            "Package files exceed the 5MB size limit.",
+            help_text = "Files over the limit: ",
+            messages = largefiles
+        )
+}
+
+checkDataFileSizes <- function(pkgdir) {
+    largedata <- .findLargeFiles(pkgdir, data_only = TRUE)
+    if (length(largedata))
+        handleWarning(
+            "Data files exceed the 5MB size limit.",
+            help_text =
+                "Use 'ExperimentHub' or 'AnnotationHub' for the files: ",
+            messages = largedata
+        )
 }
 
 .testRbuildignore <- function(text) {
@@ -205,6 +251,15 @@ checkBiocCheckOutputFolder <- function(pkgdir, pkg_name) {
         )
 }
 
+checkInstDocFolder <- function(pkgdir, pkg_name) {
+    alldirs <- list.dirs(pkgdir, full.names = FALSE)
+    instdocfiles <- list.files(file.path(pkgdir, "inst/doc"))
+    if ("inst/doc" %in% alldirs && length(instdocfiles))
+        handleError(
+            "Remove 'inst/doc' folder from the package source"
+        )
+}
+
 checkBiocViews <- function(pkgdir)
 {
     dirty <- FALSE
@@ -271,8 +326,12 @@ checkBiocViews <- function(pkgdir)
         suggestedViews <- vapply(badViews, function(view) {
             alt <- colnames(distmat)[distmat[view,]]
             msg <- shQuote(view)
-            if (length(alt))
-                msg <- paste0(msg, ": Did you mean ", shQuote(alt), "?")
+            if (length(alt)) {
+                alt <- shQuote(alt)
+                oneof <- if (length(alt) > 1L) "one of" else ""
+                alt <- paste(oneof, paste(alt, collapse = ", "))
+                msg <- paste0(msg, ": Did you mean", alt, "?")
+            }
             msg
         }, character(1))
 
@@ -521,23 +580,6 @@ checkDescriptionNamespaceConsistency <- function(pkgname, lib.loc)
     }
 }
 
-checkImportSuggestions <- function(pkgname)
-{
-    suggestions <- try(
-        suppressMessages(suppressWarnings(
-            capture.output(codetoolsBioC::writeNamespaceImports(pkgname))
-        )), silent = TRUE
-    )
-    if (inherits(suggestions, "try-error")) {
-        handleMessage("Could not get namespace suggestions.")
-    } else {
-        handleMessage("Namespace import suggestions are:")
-        handleVerbatim(suggestions, indent=4, exdent=4, width=100000)
-        handleMessage("--END of namespace import suggestions.")
-    }
-    suggestions
-}
-
 checkVignetteDir <- function(pkgdir, checkingDir)
 {
     vigdir <- file.path(pkgdir, "vignettes")
@@ -594,16 +636,11 @@ checkInstContents <- function(pkgdir, checkingDir)
 {
     instdocdir <- file.path(pkgdir, "inst", "doc")
     instdocdircontents <- getVigSources(instdocdir)
-    if (length(instdocdircontents))
-    {
-        if (checkingDir)
-        {
-            handleWarning(
-                "Remove vignette sources from inst/doc; ",
-                "they belong in vignettes/."
-            )
-        }
-    }
+    if (length(instdocdircontents) && checkingDir)
+        handleWarning(
+            "Remove vignette sources from inst/doc; ",
+            "they belong in vignettes/."
+        )
 }
 
 checkVigFiles <- function(vigdir, vigdircontents){
@@ -750,32 +787,30 @@ checkVigTemplate <- function(vigdircontents)
     badVig <- character(0)
     badVig2 <- character(0)
     for (file in vigdircontents) {
-        lines <- readLines(file, n=100L, warn=FALSE)
+        lines <- readLines(file, warn=FALSE)
+        if (identical(tolower(tools::file_ext(file)), "rmd"))
+            lines <- .getYAMLfront(lines)
         idx <- grep(lines, pattern="VignetteIndexEntry")
-        if (length(idx) != 0L){
+        if (length(idx)) {
             title <- tolower(gsub(".*\\{|\\}.*", "", lines[idx]))
-            if (title == "vignette title"){
+            if (identical(title, "vignette title"))
                 badVig <- c(badVig, basename(file))
-            }
         }
-        if (length(idx) == 0L){
+        if (!length(idx))
             badVig2 <- c(badVig2, basename(file))
-        }
     }
-    if (length(badVig) != 0L){
+    if (length(badVig))
         handleWarning(
             "Vignette(s) still using 'VignetteIndexEntry{Vignette Title}' ",
             help_text = "The following files use template defaults:",
             messages = badVig
         )
-    }
-    if (length(badVig2) != 0L){
+    if (length(badVig2))
         handleWarning(
             "Vignette(s) missing '\\%VignetteIndexEntry{Vignette Title}'. ",
             help_text = "Update the following files:",
             messages = badVig2
         )
-    }
 }
 
 checkVigChunkEval <- function(vigdircontents)
@@ -823,15 +858,15 @@ checkVigChunkEval <- function(vigdircontents)
     if (percent >= 50){
         handleWarning("Evaluate more vignette chunks.")
         msg <- sprintf(
-            "%s code chunks / %s total = %i%% percent unevaluated",
+            "%s out of %s code chunks = %i%% unevaluated",
             totnon,
             chunks,
             percent
         )
         handleMessage(msg, indent = 8)
         handleMessage(
-            sprintf("%s non-exec code chunks (e.g., '``` r')", noneval),
-            indent=8
+            sprintf("%s non-exec code chunk(s) (e.g., '```r')", noneval),
+            indent = 8
         )
     }
 }
@@ -890,6 +925,18 @@ checkVigInstalls <- function(pkgdir) {
     }
 }
 
+## Completely suppress spurious knitr:::remind_sweave() warning that shows up
+## in TclTk popup window in addition to the usual text-only warning.
+quiet_knitr_purl <- function(...)
+{
+    args <- list(...)
+    callr::r(
+        function(...) suppressWarnings(knitr::purl(...)),
+        args = args,
+        env = c(CI = "true")
+    )
+}
+
 checkVigClassUsage <- function(pkgdir) {
     vigdir <- file.path(pkgdir, "vignettes", "")
     vigfiles <- getVigSources(vigdir)
@@ -898,7 +945,7 @@ checkVigClassUsage <- function(pkgdir) {
     )
     for (vfile in vigfiles) {
         tempR <- tempfile(fileext=".R")
-        knitr::purl(input = vfile, output = tempR, quiet = TRUE)
+        quiet_knitr_purl(input = vfile, output = tempR, quiet = TRUE)
         tokens <- getClassNEEQLookup(tempR)
         viglist[[basename(vfile)]] <- sprintf(
             "%s (code line %d, column %d)",
@@ -936,7 +983,9 @@ checkVigSessionInfo <- function(pkgdir) {
             list(parseFile(vfile, pkgdir)), .Names = vfile
         )
         res <- findSymbolsInParsedCode(
-            pc, c("sessionInfo", "session_info"), "SYMBOL_FUNCTION_CALL"
+            parsedCodeList = pc,
+            symbolNames = c("sessionInfo", "session_info"),
+            tokenTypes = "SYMBOL_FUNCTION_CALL"
         )
         if (!length(res)) {
             notFoundVig[[vfile]] <- TRUE
@@ -946,7 +995,7 @@ checkVigSessionInfo <- function(pkgdir) {
         handleNote(
             " 'sessionInfo' not found in vignette(s)",
             help_text = "Missing from file(s):",
-            messages = vapply(vigfiles[notFoundVig], getDirFile, character(1L))
+            messages = .getDirFiles(vigfiles[notFoundVig])
         )
     }
 }
@@ -975,7 +1024,10 @@ findSymbolsInRFiles <-
         structure(rfiles, .Names = rfiles), parseFile, pkgdir = pkgdir
     )
     msg_res <- findSymbolsInParsedCode(
-        parsedCodes, Symbols, tokenType, fun = fun, ...
+        parsedCodeList = parsedCodes,
+        symbolNames = Symbols,
+        tokenTypes = tokenType,
+        fun = fun, ...
     )
     unlist(msg_res)
 }
@@ -988,11 +1040,11 @@ findSymbolsInVignettes <-
     viglist <- list()
     for (vfile in vigfiles) {
         tempR <- tempfile(fileext=".R")
-        knitr::purl(input = vfile, output = tempR, quiet = TRUE)
-        tokens <- FUN(parseFile(tempR), tokenTypes, Symbols)
-        viglist[[getDirFile(vfile)]] <- sprintf(
+        quiet_knitr_purl(input = vfile, output = tempR, quiet = TRUE)
+        tokens <- FUN(parseFile(tempR, pkgdir), tokenTypes, Symbols)
+        viglist[[.getDirFiles(vfile)]] <- sprintf(
             "%s (code line %d, column %d)",
-           getDirFile(vfile), tokens[,"line1"], tokens[,"col1"]
+           .getDirFiles(vfile), tokens[,"line1"], tokens[,"col1"]
         )
     }
     Filter(length, viglist)
@@ -1004,8 +1056,9 @@ checkPkgInstallCalls <- function(package_dir, badCalls = .BAD_INSTALL_CALLS) {
     )
     if (length(msg_installs)) {
         handleNote(
-            "install, biocLite, install.packages,",
-            " or update.packages found in R files",
+            "Avoid using install, biocLite, install.packages,",
+            " or update.packages",
+            help_text = "Functions in files:",
             messages = msg_installs
         )
     }
@@ -1097,7 +1150,9 @@ checkCodingPractice <- function(pkgdir, parsedCode, package_name)
     }
 
     # T/F
-    msg_tf <- findSymbolsInRFiles(pkgdir, c("T", "F"), "SYMBOL", lookback = "$")
+    msg_tf <- findSymbolsInRFiles(
+        pkgdir, c("T", "F"), "SYMBOL", lookback = "'$'"
+    )
     if (length(msg_tf)) {
         handleWarning(
             " Avoid T/F variables; If logical, use TRUE/FALSE ",
@@ -1357,7 +1412,9 @@ checkCatInRCode <-
     parsedCodes <- lapply(parsedCodes, .filtersetMethodRanges)
     parsedCodes <- lapply(parsedCodes, .filterS3printRanges)
     msg_res <- findSymbolsInParsedCode(
-        parsedCodes, symbols, c("SYMBOL_FUNCTION_CALL", "SYMBOL")
+        parsedCodeList = parsedCodes,
+        symbolNames = symbols,
+        tokenTypes = c("SYMBOL_FUNCTION_CALL", "SYMBOL")
     )
     unlist(msg_res)
 }
@@ -1369,7 +1426,10 @@ checkEqInAssignment <- function(Rdir, symbol = "=", tokenType = "EQ_ASSIGN") {
         structure(rfiles, .Names = rfiles), parseFile, pkgdir = pkgdir
     )
     msg_res <- findSymbolsInParsedCode(
-        parsedCodes, symbol, tokenType, fun = FALSE
+        parsedCodeList = parsedCodes,
+        symbolNames = symbol,
+        tokenTypes = tokenType,
+        fun = FALSE
     )
     unlist(msg_res)
 }
@@ -1455,7 +1515,7 @@ checkExternalData <- function(Rdir) {
         tokens <- getParseData(parse(rfile, keep.source=TRUE))
         tokens <- tokens[tokens[,"token"] == "STR_CONST", ,drop=FALSE]
 
-        platforms <- "githubusercontent|github.*[^html\"]$|gitlab|bitbucket|dropbox"
+        platforms <- "githubusercontent|github.*[^html\"]$|gitlab|bitbucket|[^\\.]dropbox"
         txtkns <- tokens[, "text"]
         hits <- grepl(platforms, txtkns, ignore.case = TRUE) &
             grepl("dl|\\.\\w+\"$", txtkns)
@@ -1485,7 +1545,9 @@ checkOnAttachLoadCalls <- function(Rdir) {
     })
     parsedCodes <- Filter(nrow, parsedCodes)
     msg_dl <- findSymbolsInParsedCode(
-        parsedCodes, "download.*", "SYMBOL_FUNCTION_CALL",
+        parsedCodeList = parsedCodes,
+        symbolNames = "download.*",
+        tokenTypes = "SYMBOL_FUNCTION_CALL",
         FUN = .grepTokenTextCode
     )
     unlist(msg_dl)
@@ -1506,45 +1568,42 @@ checkForDirectSlotAccess <- function(parsedCode, package_name)
 
 checkFunctionLengths <- function(parsedCode, pkgname)
 {
-    dflist <- vector("list", length(names(parsedCode)))
-    for (filename in names(parsedCode))
-    {
+    parsedCode <- parsedCode[grepl("\\.[Rr]$", names(parsedCode))]
+    if (!length(parsedCode))
+        return(invisible())
+    fileNames <- .getDirFiles(names(parsedCode))
+    dflist <- structure(
+        vector("list", length(names(parsedCode))),
+        .Names = fileNames
+    )
+    names(parsedCode) <- fileNames
+    for (filename in names(parsedCode)) {
         pc <- parsedCode[[filename]]
-        filename <- getDirFile(filename)
         res <- getFunctionLengths(pc)
         functionNames <- names(res)
         mt <- do.call(rbind, res)
+        fname <- if (is.null(functionNames)) character(0L) else filename
         df <- cbind.data.frame(
-            filename =
-                if (is.null(functionNames)) {character(0)} else {filename},
-            functionName = functionNames, mt, row.names = NULL
+            filename = fname, functionName = functionNames, mt,
+            row.names = NULL
         )
         dflist[[filename]] <- df
     }
-    dflist <- Filter(length, dflist)
+    dflist <- Filter(nrow, dflist)
     df <- do.call(rbind, dflist)
-    colnames <- c("filename","functionName","length","startLine","endLine")
-    if (!is.null(df) && ncol(df) == length(colnames))
-    {
-        colnames(df) <- colnames
-        df <- df[with(df, order(-length)),]
-        h <- df[df$length > 50,]
-        if (nrow(h))
-        {
-            h5 <- head(df, n=5)
-            fn_msg <- apply(h5, 1L, function(row) {
+    if (length(df) && nrow(df)) {
+        df <- df[order(-df[["length"]]),]
+        h <- df[df[["length"]] > 50,]
+        if (nrow(h)) {
+            fn_msg <- apply(head(h, n=5), 1L, function(row) {
                 sprintf(
                     "%s() (%s): %s lines",
                     row['functionName'], row['filename'], row['length']
                 )
             })
-            statusmsg <- paste(
-                "There are", nrow(df), "functions greater than 50 lines."
-            )
-            statusmsg <- .singularize(df, statusmsg)
             handleNote(
                 "The recommended function length is 50 lines or less. ",
-                statusmsg,
+                .nline_report(h),
                 help_text = "The longest 5 functions are:" ,
                 messages = fn_msg
             )
@@ -1552,13 +1611,15 @@ checkFunctionLengths <- function(parsedCode, pkgname)
     }
 }
 
-.singularize <- function(obj, message) {
-    thelen <- nrow(obj)
-    if (identical(thelen, 1L)) {
-        message <- gsub("are", "is", message)
-        message <- gsub("functions", "function", message)
-    }
-    message
+.nline_report <- function(data) {
+    fnoun <- "functions"
+    plural <- !identical(nrow(data), 1L)
+    mverb <- if (plural) "are" else "is"
+    if (!plural)
+        fnoun <- substr(fnoun, 1, nchar(fnoun) - 1)
+    paste(
+        "There", mverb, nrow(data), fnoun, "greater than 50 lines."
+    )
 }
 
 checkManDocumentation <- function(package_dir, package_name, libloc)
@@ -1585,7 +1646,7 @@ checkForPromptComments <- function(pkgdir)
     bad <- vapply(manpages,
         function(manpage) {
             lines <- readLines(manpage, warn=FALSE)
-            any(grepl("^%% ~", lines))
+            any(grepl("^%%\\s+~", lines))
         },
         logical(1L)
     )
@@ -1597,41 +1658,95 @@ checkForPromptComments <- function(pkgdir)
         )
 }
 
+.tagListExtract <- function(rd, tags, Tag) {
+    if (missing(tags))
+        tags <- tools:::RdTags(rd)
+    if (!Tag %in% tags)
+        character(0L)
+    else
+        unlist(rd[tags == Tag], recursive = FALSE)
+}
+
+.tagsExtract <- function(rd, tags, Tag) {
+    tagList <- .tagListExtract(rd = rd, tags = tags, Tag = Tag)
+    as.character(tagList)
+}
+
+.valueInParsedRd <- function(rd, tags) {
+    tagList <- .tagListExtract(rd, tags, "\\value")
+    values <- Filter(function(x) attr(x, "Rd_tag") != "COMMENT", tagList)
+    value <- paste(values, collapse = "")
+    nzchar(trimws(value)) && length(values)
+}
+
+.usesRdpack <- function(pkgdir) {
+    alldeps <- getAllDependencies(pkgdir)
+    "Rdpack" %in% alldeps
+}
+
+.parse_Rd_pack <- function(manpage, usesRdpack) {
+    sysfile_rdpack <- system.file(package = "Rdpack")
+    rdpack_avail <- nzchar(sysfile_rdpack)
+    if (usesRdpack && rdpack_avail)
+        rdmacros <- file.path(
+            sysfile_rdpack, "help", "macros", "refmacros.Rd"
+        )
+    else
+        rdmacros <- file.path(R.home("share"), "Rd", "macros", "system.Rd")
+
+    tools::parse_Rd(manpage, macros = rdmacros)
+}
+
+.read_all_rds <- function(pkgdir) {
+    manpages <- list.files(
+        path = file.path(pkgdir, "man"),
+        pattern = "\\.[Rr][Dd]$",
+        full.names = TRUE
+    )
+    names(manpages) <- .getDirFiles(manpages)
+    usesRdpack <- .usesRdpack(pkgdir)
+    lapply(
+        manpages,
+        function(manpage, usesRdpack) {
+            .parse_Rd_pack(manpage, usesRdpack)
+        },
+        usesRdpack = usesRdpack
+    )
+}
+
+.formatsInParsedRd <- function(rds, tags) {
+    formats <- .tagsExtract(rds, tags, "\\format")
+    value <- paste(formats, collapse = "")
+    nzchar(trimws(value)) && length(formats)
+}
+
+.isValidRdSkip <- function(rds, tags) {
+    dt <- docType(rds, tags)
+    identical(dt, "package") ||
+        (identical(dt, "data") && .formatsInParsedRd(rds, tags))
+}
+
 checkForValueSection <- function(pkgdir)
 {
-    pkgname <- basename(pkgdir)
-    manpages <- dir(file.path(pkgdir, "man"),
-        pattern="\\.Rd$", ignore.case=TRUE, full.names=TRUE)
-    ok <- vapply(manpages, function(manpage) {
-        rd <- tools::parse_Rd(manpage)
-        tags <- tools:::RdTags(rd)
-
-        type <- docType(rd)
-        if (identical(type, "data"))
-            return(TRUE)
-
-        value <- NULL
-        if ("\\usage" %in% tags && (!"\\value" %in% tags))
-            return(FALSE)
-
-        if ("\\value" %in% tags)
-            value <- rd[grep("\\value", tags)]
-
-        if ("\\usage" %in% tags && !is.null(value))
-        {
-            values <- paste(unlist(value), collapse='')
-            tst <- (is.list(value[[1]]) && length(value[[1]]) == 0) ||
-                nchar(gsub("^\\s+|\\s+$", "", values)) == 0
-            if (tst)
-                return(FALSE)
-        }
-        TRUE
-    }, logical(1))
+    all_rds <- .read_all_rds(pkgdir)
+    all_tags <- lapply(all_rds, tools:::RdTags)
+    ok <- mapply(
+        function(rds, tags) {
+            if (.isValidRdSkip(rds, tags))
+                TRUE
+            else
+                .valueInParsedRd(rds, tags)
+        },
+        rds = all_rds,
+        tags = all_tags,
+        SIMPLIFY = TRUE
+    )
     if (!all(ok)) {
-        not_oks <- vapply(manpages[!ok], getDirFile, character(1L))
-        handleWarning(
-            "Add non-empty \\value sections to the following man pages: ",
-            messages = paste(not_oks, collapse=", "))
+        not_oks <- names(ok[!ok])
+        handleWarningFiles(
+            "Empty or missing \\value sections found in man pages.",
+            messages = not_oks
+        )
     }
 }
 
@@ -1642,14 +1757,16 @@ checkExportsAreDocumented <- function(pkgdir, pkgname, lib.loc)
         pattern="\\.Rd$", ignore.case=TRUE, full.names=TRUE)
     pkg_ns <- loadNamespace(pkgname, lib.loc = lib.loc)
     exports <- getNamespaceExports(pkg_ns)
-    unloadNamespace(pkg_ns)
+    ## attempt to unload package namespace
+    try(unloadNamespace(pkg_ns), silent = TRUE)
     badManPages <- character(0)
     exportingPagesCount <- 0L
     noExamplesCount <- 0L
+    uses_rd_pack <- .usesRdpack(pkgdir)
 
     for (manpage in manpages)
     {
-        rd <- tools::parse_Rd(manpage)
+        rd <- .parse_Rd_pack(manpage, usesRdpack = uses_rd_pack)
         name <-
             unlist(rd[unlist(lapply(rd, function(x)
                 attr(x, "Rd_tag") == "\\name"))][[1]][1])
@@ -1695,10 +1812,11 @@ checkUsageOfDont <- function(pkgdir)
 
     hasBad <- rep(FALSE, length(manpages))
     hasdontrun <- rep(FALSE, length(manpages))
+    uses_rd_pack <- .usesRdpack(pkgdir)
     for (dx in seq_along(manpages))
     {
         manpage <- manpages[dx]
-        rd <- tools::parse_Rd(manpage)
+        rd <- .parse_Rd_pack(manpage, usesRdpack = uses_rd_pack)
         example <- unlist(lapply(rd,
             function(x) attr(x, "Rd_tag") == "\\examples"))
         hasExamples <- any(example)
@@ -1840,21 +1958,23 @@ checkSkipOnBioc <- function(pkgdir)
 }
 
 .lineReport <- function(linedf) {
-    apply(
-        linedf,
-        1L,
-        function(row)
-            paste0(row["File"], "#L", row["Line"], " ",
-                substr(row["Context"], 1, 40), "...")
+    paste0(
+        linedf[, "File"], "#L", linedf[, "Line"], " ",
+        substr(linedf[, "Context"], 1, 40), " ..."
     )
 }
 
 .rmYAMLfm <- function(lines) {
     fm_idx <- grep("^---\\s*$", lines)
+    offval <- 0L
     if (length(fm_idx) && !identical(length(fm_idx), 2L))
-        stop("More than 2 YAML front matter delimiters, i.e., '---' found")
-    if (length(fm_idx))
-        lines <- lines[-seq(fm_idx[1], fm_idx[2])]
+        warning("More than 2 YAML front matter delimiters, i.e., '---' found")
+    if (length(fm_idx)) {
+        offval <- max(fm_idx)
+        lines <- lines[-seq(min(fm_idx), offval)]
+    }
+    class(lines) <- c("readLines", class(lines))
+    attributes(lines) <- list(offset = offval)
     lines
 }
 
@@ -1880,28 +2000,31 @@ checkFormatting <- function(pkgdir, nlines=6)
         if (file.exists(file) && file.info(file)$size == 0)
         {
             handleNote("Add content to the empty file ",
-                getDirFile(file))
+                .getDirFiles(file))
         }
 
         if (file.exists(file) && file.info(file)$size > 0)
         {
             lines <- readLines(file, warn=FALSE)
+            offset <- 0L
             totallines <- totallines + length(lines)
 
             n <- nchar(lines, allowNA=TRUE)
             idx <- !is.na(n) & (n > 80L)
-            long <- rbind(long, Context(pkgname, file, lines, idx))
+            long <- rbind(long, Context(file, lines, idx, offset))
 
-            if (identical(tolower(tools::file_ext(file)), "rmd"))
+            if (identical(tolower(tools::file_ext(file)), "rmd")) {
                 lines <- .rmYAMLfm(lines)
+                offset <- attr(lines, "offset")
+            }
 
             idx <- grepl("\t", lines)
-            tab <- rbind(tab, Context(pkgname, file, lines, idx))
+            tab <- rbind(tab, Context(file, lines, idx, offset))
 
             res <- regexpr("^([ ]+)", lines)
             match.length <- attr(res, "match.length")
             idx <- (match.length != -1L) & (match.length %% 4 != 0)
-            indent <- rbind(indent, Context(pkgname, file, lines, idx))
+            indent <- rbind(indent, Context(file, lines, idx, offset))
         }
     }
 
@@ -1954,49 +2077,57 @@ checkFormatting <- function(pkgdir, nlines=6)
     }
 }
 
-checkIsPackageNameAlreadyInUse <- function(pkgName,
-    repo = c("CRAN", "BioCsoft", "BioCann",
-        "BioCexp", "BioCworkflows", "BioCbooks")
+checkIsPackageNameAlreadyInUse <- function(
+    pkgName,
+    repo = c(
+        "CRAN", "BioCsoft", "BioCann", "BioCexp", "BioCworkflows", "BioCbooks"
+    )
 ) {
     repo <- match.arg(repo)
+    msg <- paste0("'", pkgName, "' already exists in Bioconductor.")
 
-    if (identical(repo, "CRAN")) {
-        repo.url <- sprintf(
+    if (identical(repo, "CRAN"))
+        msg <- paste(
+            "The package already exists on CRAN. Packages submitted to",
+            "Bioconductor must be removed from CRAN before the next",
+            "Bioconductor release."
+        )
+
+    repo.url <- switch(
+        repo,
+        CRAN = sprintf(
             "%s/src/contrib/PACKAGES", BiocManager::repositories()[repo]
-        )
-    } else {
-        repo.url <- switch(
-            repo,
-            BiocSoft = "http://bioconductor.org/packages/devel/bioc/VIEWS",
-            BioCann =
-                "http://bioconductor.org/packages/devel/data/annotation/VIEWS",
-            BioCexp =
-                "http://bioconductor.org/packages/devel/data/experiment/VIEWS",
-            BioCworkflows =
-                "http://bioconductor.org/packages/devel/workflows/VIEWS",
-            BioCbooks =
-                "https://bioconductor.org/packages/devel/books/VIEWS",
-            "http://bioconductor.org/packages/devel/bioc/VIEWS"
-        )
-    }
+        ),
+        BioCsoft = "http://bioconductor.org/packages/devel/bioc/VIEWS",
+        BioCann =
+            "http://bioconductor.org/packages/devel/data/annotation/VIEWS",
+        BioCexp =
+            "http://bioconductor.org/packages/devel/data/experiment/VIEWS",
+        BioCworkflows =
+            "http://bioconductor.org/packages/devel/workflows/VIEWS",
+        BioCbooks =
+            "https://bioconductor.org/packages/devel/books/VIEWS"
+    )
 
     conn <- url(repo.url)
-    dcf <- tryCatch(suppressWarnings(read.dcf(conn)), error=identity)
-    close(conn)
-    if (inherits(dcf, "error")) {
-        handleMessage(
-            "Unable to access repository ", BiocManager::repositories()[repo]
+    on.exit({ close(conn) })
+    dcf <- try(read.dcf(conn), silent = TRUE)
+    if (is(dcf, "try-error"))
+        return(
+            handleMessage(
+                "Unable to access repository ",
+                BiocManager::repositories()[repo]
+            )
         )
-    } else if (tolower(pkgName) %in% tolower(dcf[,"Package"])) {
-        if (repo == "CRAN")
-            msg <- "Package must be removed from CRAN."
-        else {
-            msg <- paste0("'", pkgName, "' already exists in Bioconductor.")
-        }
+
+    isDuplicate <- tolower(pkgName) %in% tolower(dcf[,"Package"])
+    if (isDuplicate && identical(repo, "CRAN"))
+        handleWarning(msg)
+    else if (isDuplicate)
         handleError(msg)
-    }
 }
 
+#' @importFrom httr2 req_body_form resp_status resp_body_html
 checkForBiocDevelSubscription <- function(pkgdir)
 {
     email <- getMaintainerEmail(pkgdir)
@@ -2008,33 +2139,40 @@ checkForBiocDevelSubscription <- function(pkgdir)
         handleMessage("Maintainer email is ok.")
         return()
     }
-    response <- tryCatch({
-        POST(
-            "https://stat.ethz.ch/mailman/admin/bioc-devel",
-            body=list(adminpw=Sys.getenv("BIOC_DEVEL_PASSWORD")))
-    }, error=identity)
-    if (inherits(response, "error")) {
+    response <- try({
+        request("https://stat.ethz.ch/mailman/admin/bioc-devel") |>
+            req_body_form(
+                adminpw = Sys.getenv("BIOC_DEVEL_PASSWORD")
+            ) |>
+            req_perform()
+    }, silent = TRUE)
+    if (inherits(response, "try-error")) {
         handleMessage(
-            "Unable to connect to mailing list",
-            "\n  ", conditionMessage(response))
+            "Unable to connect to the Bioc-devel mailing list",
+            "\n  ", conditionMessage(attr(response, "condition")))
         return()
-    } else if (status_code(response) >= 300) {
+    } else if (resp_status(response) >= 300) {
         handleMessage(
-            "Unable to connect to mailing list",
-            "\n  status code ", status_code(response))
+            "Unable to connect to the Bioc-devel mailing list",
+            "\n  status code ", resp_status(response))
         return()
     }
-    response2 <- POST(
-        "https://stat.ethz.ch/mailman/admin/bioc-devel/members?letter=4",
-        body=list(findmember=email))
-    content <- content(response2, as="text")
-    if(grepl(paste0(">", tolower(email), "<"), tolower(content), fixed=TRUE))
-    {
+    response2 <- request(
+        "https://stat.ethz.ch/mailman/admin/bioc-devel/members?letter=4") |>
+        req_body_form(
+            findmember = email, adminpw = Sys.getenv("BIOC_DEVEL_PASSWORD")
+        ) |>
+        req_perform()
+    content <- resp_body_html(response2)
+    result_email <- unlist(
+        rvest::html_table(content)[[5L]][3L, 2L], use.names = FALSE
+    )
+    if (identical(tolower(result_email), tolower(email))) {
         handleMessage("Maintainer is subscribed to bioc-devel.")
     } else {
         handleError(
-            "Maintainer must subscribe to the bioc-devel mailing list. ",
-            "Subscribe here: https://stat.ethz.ch/mailman/listinfo/bioc-devel",
+            "Subscribe to the Bioc-devel mailing list by going to ",
+            "https://stat.ethz.ch/mailman/listinfo/bioc-devel",
             nframe = 3L
         )
     }
@@ -2056,56 +2194,70 @@ checkForSupportSiteRegistration <- function(package_dir)
     }
 }
 
+#' @importFrom httr2 req_perform request resp_body_json
 checkSupportReg <- function(email){
 
-    url <- paste0("https://support.bioconductor.org/api/email/", email, "/")
-    response <- tryCatch(GET(url), error=identity)
-    if (inherits(response, "error")) {
-        handleMessage(
-            "Unable to connect to support site:",
-            "\n  ", conditionMessage(response))
-        FALSE
-    } else if (suppressMessages(content(response))) {
+    url <- paste0("https://support.bioconductor.org/api/email/", email)
+    response <- try(
+        req_perform(request(url)), silent = TRUE
+    )
+    response_error <- inherits(response, "try-error")
+    result <- !response_error && resp_body_json(response)
+    if (response_error) {
+        handleError(
+            "Unable to find your email in the Support Site:",
+            "\n  ", conditionMessage(attr(response, "condition"))
+        )
+    } else if (resp_body_json(response)) {
         handleMessage("Maintainer is registered at support site.")
-        TRUE
     } else {
         handleError(
-            "Maintainer must register at the support site; ",
+            "Register your email account in the Support Site; ",
             "visit https://support.bioconductor.org/accounts/signup/"
         )
-        FALSE
     }
+    result
 }
 
 checkWatchedTag <- function(email, pkgname){
 
-    url <- paste0("https://support.bioconductor.org/api/watched/tags/", email, "/")
-    response <- tryCatch(GET(url), error=identity)
-    if (inherits(response, "error")) {
+    url <- paste0("https://support.bioconductor.org/api/watched/tags/", email)
+    response <- try(
+        req_perform(request(url)), silent = TRUE
+    )
+    if (inherits(response, "try-error")) {
         handleMessage(
-            "Unable to connect to support site:",
-            "\n  ", conditionMessage(response))
+            "Unable to find your email in the Support Site:",
+            "\n  ", conditionMessage(attr(response, "condition"))
+        )
     } else {
-        tags<-tolower(trimws(unlist(strsplit(content(response)$watched_tags, split=","))))
-        if (tolower(pkgname) %in% tags){
-            handleMessage("Package name is in support site watched tags.")
-        }else{
-            handleError("Maintainer must add package name to Watched Tags on the support site; ",
-                        "Edit your Support Site User Profile to add Watched Tags.")
-        }
+        alltags <- resp_body_json(response)[["watched_tags"]]
+        taglist <- unlist(strsplit(alltags, split = ","))
+        tags <- tolower(taglist)
+        if (tolower(pkgname) %in% tags)
+            handleMessage("Package is in the Support Site Watched Tags.")
+        else
+            handleError(
+                "Add package to Watched Tags in your Support Site profile; ",
+                "visit https://support.bioconductor.org/accounts/edit/profile"
+            )
     }
 }
 
+.HIDDEN_FILE_EXTS <- c(
+    ".renviron", ".rprofile", ".rproj", ".rproj.user", ".rhistory",
+    ".rapp.history", ".o", ".sl", ".so", ".dylib", ".a", ".dll", ".def",
+    ".ds_store", "unsrturl.bst", ".log", ".aux", ".backups", ".cproject",
+    ".directory", ".dropbox", ".exrc", ".gdb.history", ".gitattributes",
+    ".gitmodules", ".hgtags", ".project", ".seed", ".settings",
+    ".tm_properties", ".rdata"
+)
+
 # taken from
 # https://github.com/wch/r-source/blob/trunk/src/library/tools/R/build.R#L462
 # https://github.com/wch/r-source/blob/trunk/src/library/tools/R/check.R#L4025
 hidden_file_data <- data.frame(
-    file_ext = c(".renviron", ".rprofile", ".rproj", ".rproj.user", ".rhistory",
-        ".rapp.history", ".o", ".sl", ".so", ".dylib", ".a", ".dll", ".def",
-        ".ds_store", "unsrturl.bst", ".log", ".aux", ".backups", ".cproject",
-        ".directory", ".dropbox", ".exrc", ".gdb.history", ".gitattributes",
-        ".gitmodules", ".hgtags", ".project", ".seed", ".settings",
-        ".tm_properties", ".rdata"),
+    file_ext = .HIDDEN_FILE_EXTS,
     hidden_only = c(TRUE, TRUE, FALSE, TRUE, TRUE,
         TRUE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE,
         TRUE, TRUE, FALSE, FALSE, FALSE, FALSE,
@@ -2181,6 +2333,18 @@ checkBadFiles <- function(package_dir){
     }
 }
 
+.checkDESCfields <- function(dcf) {
+    handleCheck("Checking for recommeded fields in DESCRIPTION...")
+
+    fields <- c("URL", "BugReports")
+    present <- fields %in% colnames(dcf)
+    res <- fields[!present]
+    if (length(res)) {
+        notFields <- paste(shQuote(res), collapse = ", ")
+        handleNote("Provide ", notFields, " field(s) in DESCRIPTION")
+    }
+}
+
 checkDescription <- function(package_dir) {
     handleCheck("Checking if DESCRIPTION is well formatted...")
     dcf <- tryCatch({
@@ -2205,6 +2369,8 @@ checkDESCRIPTIONFile <- function(package_dir) {
     dcf <- read.dcf(file.path(package_dir, "DESCRIPTION"))
     .checkLicenseForRestrictiveUse(dcf[,"License"])
 
+    .checkDESCfields(dcf)
+
     handleCheck("Checking for pinned package versions...")
     deps <- c("Depends", "Imports", "Suggests", "Enhances", "LinkingTo")
     validdeps <- deps[deps %in% colnames(dcf)]
