@@ -117,24 +117,40 @@ installAndLoad <- function(pkgpath, install_dir = tempfile())
     dir.create(libdir <- file.path(install_dir, "lib"))
     file.create(stderr <- file.path(install_dir, "install.stderr"))
 
-    r_libs_user_old <- Sys.getenv("R_LIBS_USER")
-    on.exit(do.call("Sys.setenv", list(R_LIBS_USER=r_libs_user_old)))
     r_libs_user <- paste(c(libdir, .libPaths()), collapse=.Platform$path.sep)
-    Sys.setenv(R_LIBS_USER=r_libs_user)
+    lpath <- paste0("--library=", libdir)
+    res <- callr::rcmd_safe(
+        "INSTALL",
+        c(
+            "--no-test-load", "--use-vanilla", lpath, pkgpath
+        ),
+        env = c(callr::rcmd_safe_env(), R_LIBS_USER = r_libs_user)
+    )
 
-    rcmd <- file.path(Sys.getenv("R_HOME"), "bin", "R")
-    args <- sprintf("--vanilla CMD INSTALL --no-test-load --library=%s %s",
-                    libdir, shQuote(pkgpath))
-    res <- .run_r_command(cmd = rcmd, args = args, stderr = stderr)
-    if (res) {
+    if (!identical(res[["status"]], 0L)) {
         handleError(pkgpath, " must be installable.")
     }
     pkgname <- .getPackageName(pkgpath)
-    args <- sprintf(
-        "--vanilla -e 'library(%s)'", pkgname
+    res <- callr::r(
+        function(pkgname, libdir) {
+            tryCatch({
+                loadNamespace(
+                    package = pkgname, lib.loc = libdir
+                )
+                TRUE
+            }, error = function(e) {
+                FALSE
+            })
+        },
+        args = list(pkgname = pkgname, libdir = libdir),
+        libpath = libdir,
+        cmdargs = c(
+            "--no-save", "--no-restore", "--no-site-file",
+            "--no-init-file", "--no-environ"
+        ),
+        env = c(callr::rcmd_safe_env(), R_LIBS_USER = r_libs_user)
     )
-    res <- .run_r_command(cmd = rcmd, args = args, stderr = stderr)
-    if (res) {
+    if (!res) {
         handleError(pkgpath, " must be loadable.")
     }
     install_dir
@@ -199,7 +215,7 @@ get_status_file_cache <- function(url) {
 
     bquery <- bfcquery(bfc, url, "rname", exact = TRUE)
     if (identical(nrow(bquery), 1L) && bfcneedsupdate(bfc, bquery[["rid"]]))
-        bfcdownload(x = bfc, rid = bquery[["rid"]], rtype = "web")
+        bfcdownload(x = bfc, rid = bquery[["rid"]], rtype = "web", ask = FALSE)
 
     bfcrpath(
         bfc, rnames = url, exact = TRUE, download = TRUE, rtype = "web"
@@ -277,13 +293,14 @@ parseFile <- function(infile, pkgdir) {
         outfile <- file.path(parse_dir, "parseFile.tmp")
         suppressWarnings(suppressMessages(
             capture.output({
-                knitr::purl(
+                quiet_knitr_purl(
                     input=infile, output=outfile, documentation=0L
                 )
             })
         ))
     } else if (grepl("\\.Rd$", infile, TRUE)) {
-        rd <- tools::parse_Rd(infile)
+        uses_rd_pack <- .usesRdpack(pkgdir)
+        rd <- .parse_Rd_pack(infile, usesRdpack = uses_rd_pack)
         outfile <- file.path(parse_dir, "parseFile.tmp")
         code <- capture.output(tools::Rd2ex(rd))
         writeLines(code, con=outfile, sep="\n")
@@ -341,30 +358,31 @@ findSymbolInParsedCode <- function(parsedCode, pkgname, symbolName,
                 if (grepl("\\.R$", name, ignore.case=TRUE))
                     handleMessage(sprintf(
                         "Found %s%s in %s (line %s, column %s)", symbolName,
-                        parens, getDirFile(name), x[i,1], x[i,2]))
+                        parens, .getDirFiles(name), x[i,1], x[i,2]))
                 else
                     handleMessage(sprintf(
                         "Found %s%s in %s", symbolName, parens,
-                        getDirFile(name))) # FIXME test this
+                        .getDirFiles(name))) # FIXME test this
             }
         }
     }
     length(matches) # for tests
 }
 
-getDirFile <- function(fpath) {
-    if (!identical(length(fpath), 1L))
-        stop("<internal> 'fpath' input must be a scalar character")
-    if (nzchar(fpath) && !is.na(fpath))
-        fpath <- file.path(basename(dirname(fpath)), basename(fpath))
-
-    fpath
+.getDirFiles <- function(fpaths) {
+    if (!BiocBaseUtils::isCharacter(fpaths, zchar = TRUE, na.ok = TRUE))
+        stop("<internal> 'fpaths' input must be a character vector")
+    vapply(fpaths, function(fpath) {
+        if (nzchar(fpath) && !is.na(fpath))
+            fpath <- file.path(basename(dirname(fpath)), basename(fpath))
+        fpath
+    }, character(1L))
 }
 
 .getTokenTextCode <- function(parsedf, token, text, lookback = character(0)) {
     cond <- parsedf$token %in% token & parsedf$text %in% text
     if (length(lookback))
-        cond <- cond & parsedf$token[which(cond) - 1] != shQuote(lookback)
+        cond[cond] <- parsedf$token[which(cond) - 1] != lookback
     parsedf[
         cond,
         c("line1", "col1", "token", "text"),
@@ -424,7 +442,7 @@ findSymbolsInParsedCode <-
     apply(matches, 1L, function(rowdf) {
         fmttxt <- "%s (line %s, column %s)"
         formt <- if (fun) paste0(rowdf["text"], " in ", fmttxt) else fmttxt
-        sprintf(formt, getDirFile(rowdf["filename"]),
+        sprintf(formt, .getDirFiles(as.character(rowdf["filename"])),
             rowdf["line1"], rowdf["col1"]
         )
     })
@@ -790,13 +808,11 @@ doesManPageHaveRunnableExample <- function(rd)
     length(parsed) && !inherits(parsed, "try-error")
 }
 
-selectSome <- function(obj, maxToShow = 5) {
-    stopifnot(is.character(obj))
-    if (!maxToShow %% 2)
-        stop("'maxToShow' should be an odd value")
-    edge <- (maxToShow - 1) / 2
-    if (length(obj) > maxToShow)
-        c(head(obj, edge), "...", tail(obj, edge))
-    else
-        obj
+.getYAMLfront <- function(lines) {
+    fm_idx <- grep("^---\\s*$", lines)
+    if (length(fm_idx) && !identical(length(fm_idx), 2L))
+        stop("More than 2 YAML front matter delimiters, i.e., '---' found")
+    if (length(fm_idx))
+        lines <- lines[seq(min(fm_idx), max(fm_idx))]
+    lines
 }
