@@ -1,12 +1,16 @@
+## ----include=FALSE,results="hide",message=FALSE,warning=FALSE-----------------
+library(BiocStyle)
+
 ## ----include=TRUE,results="hide",message=FALSE,warning=FALSE------------------
 library(BiocCheck)
 
 ## ----eval=FALSE---------------------------------------------------------------
 #  BiocCheck("<packageDirOrTarball>")
 
-## ---- eval = FALSE------------------------------------------------------------
-#  if (!require("BiocManager"))
+## ----eval = FALSE-------------------------------------------------------------
+#  if (!require("BiocManager", quietly = TRUE))
 #      install.packages("BiocManager")
+#  
 #  BiocManager::install("BiocCheck")
 
 ## ----reformat_code, eval = FALSE----------------------------------------------
@@ -18,9 +22,17 @@ library(BiocCheck)
 #  styler::style_pkg(transformers = styler::tidyverse_style(indent_by = 4))
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  library(BiocCheck)
 #  BiocCheckGitClone("packageDir")
 
+## -----------------------------------------------------------------------------
+BiocCheck:::.HIDDEN_FILE_EXTS
+
+## -----------------------------------------------------------------------------
+library(utils)
+readCitationFile(
+    system.file("CITATION", package = "GenomicRanges")
+)
+
 ## ----sessionInfo--------------------------------------------------------------
 sessionInfo()
 
