@@ -322,15 +322,15 @@ test_checkBiocCheckOutputFolder <- function()
 
 test_checkInstDocFolder <- function() {
     pkg_folder <- file.path(UNIT_TEST_TEMPDIR, "testPkg")
-    inst_dir <- file.path(pkg_folder, "inst", "doc") 
+    inst_dir <- file.path(pkg_folder, "inst", "doc")
     dir.create(inst_dir, recursive = TRUE)
     BiocCheck:::checkInstDocFolder(pkg_folder, "testpkg")
     checkEqualsNumeric(.BiocCheck$getNum("error"), 0L)
-    
+
     file.create(file.path(inst_dir, "index.html"))
     BiocCheck:::checkInstDocFolder(pkg_folder, "testpkg")
     checkEqualsNumeric(.BiocCheck$getNum("error"), 1L)
-    
+
     unlink(pkg_folder, recursive = TRUE)
     .zeroCounters()
 }
@@ -414,16 +414,16 @@ test_checkIndivFileSizes <- function() {
     .findLargeFiles_org <- BiocCheck:::.findLargeFiles
     .findLargeFiles <- function(...) {
         c("fileA.rda", "fileB.rds")
-    } 
+    }
     assignInNamespace('.findLargeFiles', .findLargeFiles, "BiocCheck")
     on.exit({
         assignInNamespace('.findLargeFiles', .findLargeFiles_org, "BiocCheck")
     })
-    
+
     BiocCheck:::checkIndivFileSizes(UNIT_TEST_TEMPDIR)
     checkEqualsNumeric(.BiocCheck$getNum("warning"), 1)
     .zeroCounters()
-    
+
     BiocCheck:::checkDataFileSizes(UNIT_TEST_TEMPDIR)
     checkEqualsNumeric(.BiocCheck$getNum("warning"), 1)
     .zeroCounters()
@@ -669,20 +669,20 @@ test_checkUnitTests <- function()
     pkgdir <- system.file("testpackages", "testpkg0", package="BiocCheck")
     Rdir <- file.path(pkgdir, "R")
     msg_sapply <- BiocCheck:::checkSapply(Rdir)
-    checkTrue(length(msg_sapply) == 1)
+    checkEqualsNumeric(length(msg_sapply), 1)
     msg_seq <- BiocCheck:::check1toN(Rdir)
-    checkTrue(length(msg_seq) == 1)
+    checkEqualsNumeric(length(msg_seq), 1)
     msg_eda <- BiocCheck:::checkExternalData(Rdir)
-    checkTrue(length(msg_eda) == 4)
+    checkEqualsNumeric(length(msg_eda), 4)
     msg_dl <- BiocCheck:::checkOnAttachLoadCalls(Rdir)
-    checkTrue(length(msg_dl) == 2)
+    checkEqualsNumeric(length(msg_dl), 2)
     avail_pkgs <- BiocManager::available()
     msg_sc <- BiocCheck:::checkSingleColon(Rdir, avail_pkgs)
     testval <- ifelse("BiocCheck" %in% avail_pkgs, 1, 0)
     checkTrue(length(msg_sc) == testval)
     pkgdir <- system.file("testpackages", "testpkg2", package="BiocCheck")
     res <- BiocCheck:::findSymbolsInVignettes(pkgdir, c("T", "F"), "SYMBOL")
-    checkTrue(length(res) == 1)
+    checkEqualsNumeric(length(res), 1)
 }
 
 test_findPasteInSignaler <- function() {
@@ -786,8 +786,11 @@ test_checkForBrowser <- function()
     if (is.null(parsedCode))
         parsedCode <- BiocCheck:::parseFiles(system.file("testpackages",
             "testpkg0", package="BiocCheck"))
-    res <- BiocCheck:::findSymbolsInParsedCode(parsedCode, "browser",
-        "SYMBOL_FUNCTION_CALL")
+    res <- BiocCheck:::findSymbolsInParsedCode(
+        parsedCodeList = parsedCode,
+        symbolNames = "browser",
+        tokenTypes = "SYMBOL_FUNCTION_CALL"
+    )
     checkTrue(length(res) == 1)
 }
 
@@ -894,6 +897,27 @@ test_checkClassNEEQLookup <- function()
     checkIdentical(4L, length(match))
 }
 
+test_checkDESCRIPTIONfile <- function()
+{
+    dcf <- matrix("https://example.com", dimnames = list(NULL, "URL"))
+    BiocCheck:::.checkDESCfields(dcf)
+    checkEqualsNumeric(.BiocCheck$getNum("note"), 1)
+    .zeroCounters()
+
+    dcf <- matrix("https://example.com", dimnames = list(NULL, "BugReports"))
+    BiocCheck:::.checkDESCfields(dcf)
+    checkEqualsNumeric(.BiocCheck$getNum("note"), 1)
+    .zeroCounters()
+
+    dcf <- matrix(
+        c("https://example.com", "https://example.com"), nrow = 1,
+        dimnames = list(NULL, c("BugReports", "URL"))
+    )
+    BiocCheck:::.checkDESCfields(dcf)
+    checkEqualsNumeric(.BiocCheck$getNum("note"), 0)
+    .zeroCounters()
+}
+
 test_checkDescriptionNamespaceConsistency <- function()
 {
     run_check <- function(pkg, instdir) {
@@ -988,7 +1012,7 @@ test_checkDescriptionNamespaceConsistency <- function()
     checkTrue(
         "devtools" %in% names(getNamespaceImports(pkg_ns))
     )
-    unloadNamespace(pkg_ns)
+    try(unloadNamespace(pkg_ns), silent = TRUE)
 
     run_check(pkgname, instdir)
     checkTrue(.BiocCheck$getNum("warning") == 1)
@@ -1051,13 +1075,13 @@ test_getFunctionLengths2 <- function()
     load(system.file("unitTests", "IRangesParsedCode.rda", package="BiocCheck"))
     BiocCheck:::checkFunctionLengths(IRangesParsedCode, "IRanges")
     .zeroCounters()
-    
+
     ## we should find 1 function that is greater than 50 lines long
     parsedCode <- BiocCheck:::parseFiles(system.file("testpackages", "testpkg0",
                                                      package="BiocCheck"))
     res <- BiocCheck:::checkFunctionLengths(parsedCode, "testpkg0")
     checkEqualsNumeric(BiocCheck:::.BiocCheck$getNum("note"), 1)
-    checkTrue(grepl(pattern = "There is 1 function greater than 50 lines", 
+    checkTrue(grepl(pattern = "There is 1 function greater than 50 lines",
                     x = BiocCheck:::.BiocCheck$note$checkFunctionLengths[[1]]),
               msg = "Checking we report functions > 50 lines long.")
     .zeroCounters()
@@ -1328,19 +1352,21 @@ test_doesManPageHaveRunnableExample <- function()
 }
 
 test_checkForValueSection <- function() {
-    man <- system.file(
-        "testpackages", "testpkg0", "man", package = "BiocCheck"
+    pkgdir <- system.file(
+        "testpackages", "testpkg0", package = "BiocCheck"
     )
-    mans <- list.files(man, full.names = TRUE)
-    checkTrue(!BiocCheck:::.valueInManPage(mans[1]))
-    checkTrue(!BiocCheck:::.valueInManPage(mans[2]))
-    checkTrue(BiocCheck:::.valueInManPage(mans[3]))
-    man <- system.file(
-        "testpackages", "testpkg1", "man", package = "BiocCheck"
+    mans <- BiocCheck:::.read_all_rds(pkgdir)
+    tags <- lapply(mans, tools:::RdTags)
+    checkTrue(!BiocCheck:::.valueInParsedRd(mans[[1]], tags[[1]]))
+    checkTrue(!BiocCheck:::.valueInParsedRd(mans[[2]], tags[[2]]))
+    checkTrue(BiocCheck:::.valueInParsedRd(mans[[3]], tags[[3]]))
+    pkgdir <- system.file(
+        "testpackages", "testpkg1", package = "BiocCheck"
     )
-    mans <- list.files(man, full.names = TRUE)
-    checkTrue(!BiocCheck:::.valueInManPage(mans[1]))
-    checkTrue(!BiocCheck:::.valueInManPage(mans[2]))
+    mans <- BiocCheck:::.read_all_rds(pkgdir)
+    tags <- lapply(mans, tools:::RdTags)
+    checkTrue(!BiocCheck:::.valueInParsedRd(mans[[1]], tags[[1]]))
+    checkTrue(!BiocCheck:::.valueInParsedRd(mans[[2]], tags[[2]]))
 }
 
 test_packageAlreadyExists <- function()
@@ -1446,21 +1472,18 @@ test_getBiocCheckDir <- function() {
     )
 }
 
-test_getDirFile <- function() {
-    getDirFile <- BiocCheck:::getDirFile
-    vigfile <- system.file(
-        "testpackages", "testpkg0", "vignettes", "evalfalse.Rmd",
-        package="BiocCheck"
-    )
-    checkIdentical("vignettes/evalfalse.Rmd", getDirFile(vigfile))
-
+test_getDirFiles <- function() {
     vigfiles <- list.files(
         system.file(
             "testpackages", "testpkg0", "vignettes", package="BiocCheck"
         ),
         full.names = TRUE
     )
-    checkException(getDirFile(vigfiles))
+    targets <- file.path(basename(dirname(vigfiles)), basename(vigfiles))
+    checkIdentical(
+        targets[1], unname(BiocCheck:::.getDirFiles(vigfiles[1]))
+    )
+    checkIdentical(targets, unname(BiocCheck:::.getDirFiles(vigfiles)))
 }
 
 
